#pragma once

namespace securefs
{
extern const char* const GIT_VERSION;
}